@@ -4,8 +4,72 @@ use warnings;
 use 5.010; # state
 
 # ABSTRACT: Fully UTF-8 aware File::Find
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 
+#pod =for test_synopsis
+#pod my @directories_to_search;
+#pod
+#pod =head1 SYNOPSIS
+#pod
+#pod     # Use the utf-8 versions of find and finddepth
+#pod     use File::Find::utf8;
+#pod     find(\&wanted, @directories_to_search);
+#pod
+#pod     # Revert back to non-utf-8 versions
+#pod     no File::Find::utf8;
+#pod     finddepth(\&wanted, @directories_to_search);
+#pod
+#pod     # Export only the find function
+#pod     use File::Find::utf8 qw(find);
+#pod     find(\&wanted, @directories_to_search);
+#pod
+#pod     # Export no functions
+#pod     use File::Find::utf8 qw(:none); # NOT "use File::Find::utf8 qw();"!
+#pod     File::Find::find(\&wanted, @directories_to_search);
+#pod
+#pod =head1 DESCRIPTION
+#pod
+#pod While the original L<File::Find> functions are capable of handling
+#pod UTF-8 quite well, they expect and return all data as bytes, not as
+#pod characters.
+#pod
+#pod This module replaces the L<File::Find> functions with fully UTF-8
+#pod aware versions, both expecting and returning characters.
+#pod
+#pod B<Note:> Replacement of functions is not done on DOS and OS/2
+#pod as these systems do not have full UTF-8 file system support.
+#pod
+#pod =head2 Behaviour
+#pod
+#pod The module behaves as a pragma so you can use both C<use
+#pod File::Find::utf8> and C<no File::Find::utf8> to turn utf-8 support on
+#pod or off.
+#pod
+#pod By default, both find() and finddepth() are exported (as with the original
+#pod L<File::Find>), if you want to prevent this, use C<use File::Find::utf8
+#pod qw(:none)>. (As all the magic happens in the module's import function,
+#pod you can not simply use C<use File::Find::utf8 qw()>)
+#pod
+#pod L<File::Find> warning levels are properly propagated. Note though that
+#pod for propagation of fatal L<File::Find> warnings, Perl 5.12 or higher
+#pod is required (or the appropriate version of L<warnings>).
+#pod
+#pod =head1 COMPATIBILITY
+#pod
+#pod The filesystems of Dos, Windows, and OS/2 do not (fully) support
+#pod UTF-8. The L<File::Find> function will therefore not be replaced on these
+#pod systems.
+#pod
+#pod =head1 SEE ALSO
+#pod
+#pod =for :list
+#pod * L<File::Find> -- The original module.
+#pod * L<Cwd::utf8> -- Fully utf-8 aware version of the L<Cwd> functions.
+#pod * L<utf8::all> -- Turn on utf-8, all of it.
+#pod   This was also the module I first added the utf-8 aware versions of
+#pod   L<Cwd> and L<File::Find> to before moving them to their own package.
+#pod
+#pod =cut
 
 use File::Find qw();
 use Encode;
@@ -30,9 +94,9 @@ sub import {
     no strict qw(refs); ## no critic (TestingAndDebugging::ProhibitNoStrict)
     no warnings qw(redefine);
 
-    # If run on the DOS or OS/2 platform, ignore overriding functions silently.
-    # These platforms do not (properly) suppport utf-8 filenames...
-    unless ($^O eq 'dos' or $^O eq 'os2') {
+    # If run on the dos/os2/windows platform, ignore overriding functions silently.
+    # These platforms do have (proper) utf-8 file system suppport...
+    unless ($^O =~ /MSWin32|cygwin|dos|os2/) {
         no strict qw(refs); ## no critic (TestingAndDebugging::ProhibitNoStrict)
         no warnings qw(redefine);
 
@@ -68,14 +132,18 @@ sub import {
             *{$target_package . '::' . $f} = \&{$original_package . '::' . $f};
         }
     }
+
+    return;
 }
 
 sub unimport {
     # If run on the dos/os2/windows platform, ignore overriding functions silently.
-    # These platforms do not (properly) suppport utf-8 filenames...
-    unless ($^O eq 'Win32' or $^O eq 'dos' or $^O eq 'os2') {
+    # These platforms do have (proper) utf-8 file system suppport...
+    unless ($^O =~ /MSWin32|cygwin|dos|os2/) {
         $^H{$current_package} = 0; # Set compiler hint that we should not use the utf-8 version
     }
+
+    return;
 }
 
 sub _utf8_find {
@@ -146,7 +214,7 @@ File::Find::utf8 - Fully UTF-8 aware File::Find
 
 =head1 VERSION
 
-version 0.004
+version 0.005
 
 =head1 SYNOPSIS
 
@@ -195,21 +263,36 @@ is required (or the appropriate version of L<warnings>).
 
 =for test_synopsis my @directories_to_search;
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+https://github.com/HayoBaan/File-Find-utf8/issues
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COMPATIBILITY
+
+The filesystems of Dos, Windows, and OS/2 do not (fully) support
+UTF-8. The L<File::Find> function will therefore not be replaced on these
+systems.
+
 =head1 SEE ALSO
 
 =over 4
 
 =item *
 
-L<File::Find>
+L<File::Find> -- The original module.
 
 =item *
 
-L<Cwd::utf8>
+L<Cwd::utf8> -- Fully utf-8 aware version of the L<Cwd> functions.
 
 =item *
 
-L<utf8::all>
+L<utf8::all> -- Turn on utf-8, all of it. This was also the module I first added the utf-8 aware versions of L<Cwd> and L<File::Find> to before moving them to their own package.
 
 =back
 
